# coding: utf-8

"""


    
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.api.apps_api import AppsApi  # noqa: E501
from swagger_client.rest import ApiException


class TestAppsApi(unittest.TestCase):
    """AppsApi unit test stubs"""

    def setUp(self):
        self.api = swagger_client.api.apps_api.AppsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_recommended_app_list(self):
        """Test case for get_recommended_app_list

        get recommended app list  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
