# coding: utf-8

"""


    
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import unittest

import swagger_client
from swagger_client.models.store_app_version import StoreAppVersion  # noqa: E501
from swagger_client.rest import ApiException


class TestStoreAppVersion(unittest.TestCase):
    """StoreAppVersion unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testStoreAppVersion(self):
        """Test StoreAppVersion"""
        # FIXME: construct object with mandatory attributes with example values
        # model = swagger_client.models.store_app_version.StoreAppVersion()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
