# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StoreAppVersionTempleteAppDepService(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'dep_service_key': 'str'
    }

    attribute_map = {
        'dep_service_key': 'dep_service_key'
    }

    def __init__(self, dep_service_key=None):  # noqa: E501
        """StoreAppVersionTempleteAppDepService - a model defined in Swagger"""  # noqa: E501

        self._dep_service_key = None
        self.discriminator = None

        if dep_service_key is not None:
            self.dep_service_key = dep_service_key

    @property
    def dep_service_key(self):
        """Gets the dep_service_key of this StoreAppVersionTempleteAppDepService.  # noqa: E501


        :return: The dep_service_key of this StoreAppVersionTempleteAppDepService.  # noqa: E501
        :rtype: str
        """
        return self._dep_service_key

    @dep_service_key.setter
    def dep_service_key(self, dep_service_key):
        """Sets the dep_service_key of this StoreAppVersionTempleteAppDepService.


        :param dep_service_key: The dep_service_key of this StoreAppVersionTempleteAppDepService.  # noqa: E501
        :type: str
        """

        self._dep_service_key = dep_service_key

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreAppVersionTempleteAppDepService, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreAppVersionTempleteAppDepService):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
