# coding: utf-8

"""
    rainbond cloud app market OpenAPI.

    the purpose of this application is to provide an application that is using plain go code to define an API  This should demonstrate all the possible comment annotations that are available to turn go code into a fully compliant swagger 2.0 spec  # noqa: E501

    OpenAPI spec version: 0.0.1
    Contact: 576501057@qq.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class StoreAppTag(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'app_tag_desc': 'str',
        'app_tag_id': 'str',
        'app_tag_name': 'str',
        'logo': 'str',
        'sort': 'int'
    }

    attribute_map = {
        'app_tag_desc': 'app_tag_desc',
        'app_tag_id': 'app_tag_id',
        'app_tag_name': 'app_tag_name',
        'logo': 'logo',
        'sort': 'sort'
    }

    def __init__(self, app_tag_desc=None, app_tag_id=None, app_tag_name=None, logo=None, sort=None):  # noqa: E501
        """StoreAppTag - a model defined in Swagger"""  # noqa: E501

        self._app_tag_desc = None
        self._app_tag_id = None
        self._app_tag_name = None
        self._logo = None
        self._sort = None
        self.discriminator = None

        if app_tag_desc is not None:
            self.app_tag_desc = app_tag_desc
        if app_tag_id is not None:
            self.app_tag_id = app_tag_id
        if app_tag_name is not None:
            self.app_tag_name = app_tag_name
        if logo is not None:
            self.logo = logo
        if sort is not None:
            self.sort = sort

    @property
    def app_tag_desc(self):
        """Gets the app_tag_desc of this StoreAppTag.  # noqa: E501


        :return: The app_tag_desc of this StoreAppTag.  # noqa: E501
        :rtype: str
        """
        return self._app_tag_desc

    @app_tag_desc.setter
    def app_tag_desc(self, app_tag_desc):
        """Sets the app_tag_desc of this StoreAppTag.


        :param app_tag_desc: The app_tag_desc of this StoreAppTag.  # noqa: E501
        :type: str
        """

        self._app_tag_desc = app_tag_desc

    @property
    def app_tag_id(self):
        """Gets the app_tag_id of this StoreAppTag.  # noqa: E501


        :return: The app_tag_id of this StoreAppTag.  # noqa: E501
        :rtype: str
        """
        return self._app_tag_id

    @app_tag_id.setter
    def app_tag_id(self, app_tag_id):
        """Sets the app_tag_id of this StoreAppTag.


        :param app_tag_id: The app_tag_id of this StoreAppTag.  # noqa: E501
        :type: str
        """

        self._app_tag_id = app_tag_id

    @property
    def app_tag_name(self):
        """Gets the app_tag_name of this StoreAppTag.  # noqa: E501


        :return: The app_tag_name of this StoreAppTag.  # noqa: E501
        :rtype: str
        """
        return self._app_tag_name

    @app_tag_name.setter
    def app_tag_name(self, app_tag_name):
        """Sets the app_tag_name of this StoreAppTag.


        :param app_tag_name: The app_tag_name of this StoreAppTag.  # noqa: E501
        :type: str
        """

        self._app_tag_name = app_tag_name

    @property
    def logo(self):
        """Gets the logo of this StoreAppTag.  # noqa: E501


        :return: The logo of this StoreAppTag.  # noqa: E501
        :rtype: str
        """
        return self._logo

    @logo.setter
    def logo(self, logo):
        """Sets the logo of this StoreAppTag.


        :param logo: The logo of this StoreAppTag.  # noqa: E501
        :type: str
        """

        self._logo = logo

    @property
    def sort(self):
        """Gets the sort of this StoreAppTag.  # noqa: E501


        :return: The sort of this StoreAppTag.  # noqa: E501
        :rtype: int
        """
        return self._sort

    @sort.setter
    def sort(self, sort):
        """Sets the sort of this StoreAppTag.


        :param sort: The sort of this StoreAppTag.  # noqa: E501
        :type: int
        """

        self._sort = sort

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StoreAppTag, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StoreAppTag):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
